@@ -89,7 +89,7 @@ try:
     }
     response = requests.post(url=jenkins_callback_url, files=payload,
                              auth=(jenkins_callback_username, jenkins_callback_token))
-    print(response.raw)
+    print(response.text)
 
 
     print("script completed")
